
# Slot: imports


other schemas that are included in this schema

URI: [linkml:imports](https://w3id.org/linkml/imports)


## Domain and Range

[SchemaDefinition](SchemaDefinition.md) &#8594;  <sub>0..\*</sub> [Uriorcurie](types/Uriorcurie.md)

## Parents


## Children


## Used by

 * [SchemaDefinition](SchemaDefinition.md)
